@@ -23,7 +23,6 @@
 #undef explicit
 
 
-#include <QX11Info>
 #include <QCoreApplication>
 #include <QDebug>
 
@@ -32,7 +31,6 @@
 #include <X11/Xatom.h>
 #include <X11/XKBlib.h>
 #include <X11/extensions/XKBrules.h>
-#include <xcb/xcb.h>
 #include <fixx11h.h>
 
 // more information about the limit https://bugs.freedesktop.org/show_bug.cgi?id=19501
